@@ -4,7 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![Stability: Stable](https://img.shields.io/badge/stability-Stable-success.svg?style=for-the-badge)
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -54,7 +54,7 @@ import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-events-targets", "1.32.2", __name__, "aws-events-targets@1.32.2.jsii.tgz")
+from ._jsii import *
 
 
 @jsii.implements(aws_cdk.aws_events.IRuleTarget)
@@ -85,7 +85,7 @@ class AwsApi(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targets.Aws
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.AwsApiInput", jsii_struct_bases=[], name_mapping={'action': 'action', 'service': 'service', 'api_version': 'apiVersion', 'catch_error_pattern': 'catchErrorPattern', 'parameters': 'parameters'})
 class AwsApiInput():
-    def __init__(self, *, action: str, service: str, api_version: typing.Optional[str]=None, catch_error_pattern: typing.Optional[str]=None, parameters: typing.Any=None):
+    def __init__(self, *, action: str, service: str, api_version: typing.Optional[str]=None, catch_error_pattern: typing.Optional[str]=None, parameters: typing.Any=None) -> None:
         """Rule target input for an AwsApi target.
 
         :param action: The service action to call.
@@ -169,7 +169,7 @@ class AwsApiInput():
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.AwsApiProps", jsii_struct_bases=[AwsApiInput], name_mapping={'action': 'action', 'service': 'service', 'api_version': 'apiVersion', 'catch_error_pattern': 'catchErrorPattern', 'parameters': 'parameters', 'policy_statement': 'policyStatement'})
 class AwsApiProps(AwsApiInput):
-    def __init__(self, *, action: str, service: str, api_version: typing.Optional[str]=None, catch_error_pattern: typing.Optional[str]=None, parameters: typing.Any=None, policy_statement: typing.Optional[aws_cdk.aws_iam.PolicyStatement]=None):
+    def __init__(self, *, action: str, service: str, api_version: typing.Optional[str]=None, catch_error_pattern: typing.Optional[str]=None, parameters: typing.Any=None, policy_statement: typing.Optional[aws_cdk.aws_iam.PolicyStatement]=None) -> None:
         """Properties for an AwsApi target.
 
         :param action: The service action to call.
@@ -303,7 +303,7 @@ class BatchJob(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targets.B
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.BatchJobProps", jsii_struct_bases=[], name_mapping={'attempts': 'attempts', 'event': 'event', 'job_name': 'jobName', 'size': 'size'})
 class BatchJobProps():
-    def __init__(self, *, attempts: typing.Optional[jsii.Number]=None, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None, job_name: typing.Optional[str]=None, size: typing.Optional[jsii.Number]=None):
+    def __init__(self, *, attempts: typing.Optional[jsii.Number]=None, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None, job_name: typing.Optional[str]=None, size: typing.Optional[jsii.Number]=None) -> None:
         """Customize the Batch Job Event Target.
 
         :param attempts: The number of times to attempt to retry, if the job fails. Valid values are 1–10. Default: no retryStrategy is set
@@ -409,7 +409,7 @@ class CodeBuildProject(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-t
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.CodeBuildProjectProps", jsii_struct_bases=[], name_mapping={'event': 'event'})
 class CodeBuildProjectProps():
-    def __init__(self, *, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None):
+    def __init__(self, *, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None) -> None:
         """Customize the CodeBuild Event Target.
 
         :param event: The event to send to CodeBuild. This will be the payload for the StartBuild API. Default: - the entire CloudWatch event
@@ -465,7 +465,7 @@ class CodePipeline(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targe
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.CodePipelineTargetOptions", jsii_struct_bases=[], name_mapping={'event_role': 'eventRole'})
 class CodePipelineTargetOptions():
-    def __init__(self, *, event_role: typing.Optional[aws_cdk.aws_iam.IRole]=None):
+    def __init__(self, *, event_role: typing.Optional[aws_cdk.aws_iam.IRole]=None) -> None:
         """Customization options when creating a {@link CodePipeline} event target.
 
         :param event_role: The role to assume before invoking the target (i.e., the pipeline) when the given rule is triggered. Default: - a new role will be created
@@ -495,7 +495,7 @@ class CodePipelineTargetOptions():
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.ContainerOverride", jsii_struct_bases=[], name_mapping={'container_name': 'containerName', 'command': 'command', 'cpu': 'cpu', 'environment': 'environment', 'memory_limit': 'memoryLimit', 'memory_reservation': 'memoryReservation'})
 class ContainerOverride():
-    def __init__(self, *, container_name: str, command: typing.Optional[typing.List[str]]=None, cpu: typing.Optional[jsii.Number]=None, environment: typing.Optional[typing.List["TaskEnvironmentVariable"]]=None, memory_limit: typing.Optional[jsii.Number]=None, memory_reservation: typing.Optional[jsii.Number]=None):
+    def __init__(self, *, container_name: str, command: typing.Optional[typing.List[str]]=None, cpu: typing.Optional[jsii.Number]=None, environment: typing.Optional[typing.List["TaskEnvironmentVariable"]]=None, memory_limit: typing.Optional[jsii.Number]=None, memory_reservation: typing.Optional[jsii.Number]=None) -> None:
         """
         :param container_name: Name of the container inside the task definition.
         :param command: Command to run inside the container. Default: Default command
@@ -602,7 +602,7 @@ class EcsTask(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targets.Ec
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.EcsTaskProps", jsii_struct_bases=[], name_mapping={'cluster': 'cluster', 'task_definition': 'taskDefinition', 'container_overrides': 'containerOverrides', 'security_group': 'securityGroup', 'subnet_selection': 'subnetSelection', 'task_count': 'taskCount'})
 class EcsTaskProps():
-    def __init__(self, *, cluster: aws_cdk.aws_ecs.ICluster, task_definition: aws_cdk.aws_ecs.TaskDefinition, container_overrides: typing.Optional[typing.List["ContainerOverride"]]=None, security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]=None, subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection]=None, task_count: typing.Optional[jsii.Number]=None):
+    def __init__(self, *, cluster: aws_cdk.aws_ecs.ICluster, task_definition: aws_cdk.aws_ecs.TaskDefinition, container_overrides: typing.Optional[typing.List["ContainerOverride"]]=None, security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]=None, subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection]=None, task_count: typing.Optional[jsii.Number]=None) -> None:
         """Properties to define an ECS Event Task.
 
         :param cluster: Cluster where service will be deployed.
@@ -706,7 +706,7 @@ class LambdaFunction(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-tar
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.LambdaFunctionProps", jsii_struct_bases=[], name_mapping={'event': 'event'})
 class LambdaFunctionProps():
-    def __init__(self, *, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None):
+    def __init__(self, *, event: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None) -> None:
         """Customize the Lambda Event Target.
 
         :param event: The event to send to the Lambda. This will be the payload sent to the Lambda Function. Default: the entire CloudWatch event
@@ -768,7 +768,7 @@ class SfnStateMachine(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-ta
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.SfnStateMachineProps", jsii_struct_bases=[], name_mapping={'input': 'input'})
 class SfnStateMachineProps():
-    def __init__(self, *, input: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None):
+    def __init__(self, *, input: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None) -> None:
         """Customize the Step Functions State Machine target.
 
         :param input: The input to the state machine execution. Default: the entire CloudWatch event
@@ -836,7 +836,7 @@ class SnsTopic(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targets.S
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.SnsTopicProps", jsii_struct_bases=[], name_mapping={'message': 'message'})
 class SnsTopicProps():
-    def __init__(self, *, message: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None):
+    def __init__(self, *, message: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None) -> None:
         """Customize the SNS Topic Event Target.
 
         :param message: The message to send to the topic. Default: the entire CloudWatch event
@@ -905,7 +905,7 @@ class SqsQueue(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-events-targets.S
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.SqsQueueProps", jsii_struct_bases=[], name_mapping={'message': 'message', 'message_group_id': 'messageGroupId'})
 class SqsQueueProps():
-    def __init__(self, *, message: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None, message_group_id: typing.Optional[str]=None):
+    def __init__(self, *, message: typing.Optional[aws_cdk.aws_events.RuleTargetInput]=None, message_group_id: typing.Optional[str]=None) -> None:
         """Customize the SQS Queue Event Target.
 
         :param message: The message to send to the queue. Must be a valid JSON text passed to the target queue. Default: the entire CloudWatch event
@@ -950,7 +950,7 @@ class SqsQueueProps():
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-events-targets.TaskEnvironmentVariable", jsii_struct_bases=[], name_mapping={'name': 'name', 'value': 'value'})
 class TaskEnvironmentVariable():
-    def __init__(self, *, name: str, value: str):
+    def __init__(self, *, name: str, value: str) -> None:
         """An environment variable to be set in the container run as a task.
 
         :param name: Name for the environment variable. Exactly one of ``name`` and ``namePath`` must be specified.
@@ -987,6 +987,28 @@ class TaskEnvironmentVariable():
         return 'TaskEnvironmentVariable(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["AwsApi", "AwsApiInput", "AwsApiProps", "BatchJob", "BatchJobProps", "CodeBuildProject", "CodeBuildProjectProps", "CodePipeline", "CodePipelineTargetOptions", "ContainerOverride", "EcsTask", "EcsTaskProps", "LambdaFunction", "LambdaFunctionProps", "SfnStateMachine", "SfnStateMachineProps", "SnsTopic", "SnsTopicProps", "SqsQueue", "SqsQueueProps", "TaskEnvironmentVariable", "__jsii_assembly__"]
+__all__ = [
+    "AwsApi",
+    "AwsApiInput",
+    "AwsApiProps",
+    "BatchJob",
+    "BatchJobProps",
+    "CodeBuildProject",
+    "CodeBuildProjectProps",
+    "CodePipeline",
+    "CodePipelineTargetOptions",
+    "ContainerOverride",
+    "EcsTask",
+    "EcsTaskProps",
+    "LambdaFunction",
+    "LambdaFunctionProps",
+    "SfnStateMachine",
+    "SfnStateMachineProps",
+    "SnsTopic",
+    "SnsTopicProps",
+    "SqsQueue",
+    "SqsQueueProps",
+    "TaskEnvironmentVariable",
+]
 
 publication.publish()
